@@ -24,8 +24,9 @@ Usage::
     query_table_rows_paginator: QueryTableRowsPaginator = client.get_paginator("query_table_rows")
     ```
 """
-from typing import Iterator, List
+from typing import Generic, Iterator, List, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
@@ -45,24 +46,34 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListTableColumnsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
     """
 
     def paginate(
         self, *, workbookId: str, tableId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTableColumnsResultTypeDef]:
+    ) -> _PageIterator[ListTableColumnsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
         """
 
 
 class ListTableRowsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
     """
 
@@ -73,31 +84,31 @@ class ListTableRowsPaginator(Boto3Paginator):
         tableId: str,
         rowIds: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTableRowsResultTypeDef]:
+    ) -> _PageIterator[ListTableRowsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
     """
 
     def paginate(
         self, *, workbookId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTablesResultTypeDef]:
+    ) -> _PageIterator[ListTablesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
         """
 
 
 class QueryTableRowsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
     """
 
@@ -108,8 +119,8 @@ class QueryTableRowsPaginator(Boto3Paginator):
         tableId: str,
         filterFormula: "FilterTypeDef",
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[QueryTableRowsResultTypeDef]:
+    ) -> _PageIterator[QueryTableRowsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
         """
